@@ -37,13 +37,13 @@
  *
  * @par Thanks:
  * Thanks a bunch to the holographic unfolding pattern.
-*/
+ */
 
 #ifndef vtkGraphLayoutView_h
 #define vtkGraphLayoutView_h
 
-#include "vtkViewsInfovisModule.h" // For export macro
 #include "vtkRenderView.h"
+#include "vtkViewsInfovisModule.h" // For export macro
 
 class vtkEdgeLayoutStrategy;
 class vtkGraphLayoutStrategy;
@@ -53,165 +53,165 @@ class vtkViewTheme;
 class VTKVIEWSINFOVIS_EXPORT vtkGraphLayoutView : public vtkRenderView
 {
 public:
-  static vtkGraphLayoutView *New();
+  static vtkGraphLayoutView* New();
   vtkTypeMacro(vtkGraphLayoutView, vtkRenderView);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The array to use for vertex labeling.  Default is "VertexDegree".
    */
   void SetVertexLabelArrayName(const char* name);
   const char* GetVertexLabelArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array to use for edge labeling.  Default is "LabelText".
    */
   void SetEdgeLabelArrayName(const char* name);
   const char* GetEdgeLabelArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to show vertex labels.  Default is off.
    */
   void SetVertexLabelVisibility(bool vis);
   bool GetVertexLabelVisibility();
   vtkBooleanMacro(VertexLabelVisibility, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to hide vertex labels during mouse interactions.  Default is off.
    */
   void SetHideVertexLabelsOnInteraction(bool vis);
   bool GetHideVertexLabelsOnInteraction();
   vtkBooleanMacro(HideVertexLabelsOnInteraction, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to show the edges at all. Default is on
    */
   void SetEdgeVisibility(bool vis);
   bool GetEdgeVisibility();
   vtkBooleanMacro(EdgeVisibility, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to show edge labels.  Default is off.
    */
   void SetEdgeLabelVisibility(bool vis);
   bool GetEdgeLabelVisibility();
   vtkBooleanMacro(EdgeLabelVisibility, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to hide edge labels during mouse interactions.  Default is off.
    */
   void SetHideEdgeLabelsOnInteraction(bool vis);
   bool GetHideEdgeLabelsOnInteraction();
   vtkBooleanMacro(HideEdgeLabelsOnInteraction, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array to use for coloring vertices.  The default behavior
    * is to color by vertex degree.
    */
   void SetVertexColorArrayName(const char* name);
   const char* GetVertexColorArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to color vertices.  Default is off.
    */
   void SetColorVertices(bool vis);
   bool GetColorVertices();
   vtkBooleanMacro(ColorVertices, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array to use for coloring edges.  Default is "color".
    */
   void SetEdgeColorArrayName(const char* name);
   const char* GetEdgeColorArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to color edges.  Default is off.
    */
   void SetColorEdges(bool vis);
   bool GetColorEdges();
   vtkBooleanMacro(ColorEdges, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether edges are selectable. Default is on.
    */
   void SetEdgeSelection(bool vis);
   bool GetEdgeSelection();
   vtkBooleanMacro(EdgeSelection, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array to use for coloring edges.
    */
   void SetEnabledEdgesArrayName(const char* name);
   const char* GetEnabledEdgesArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to color edges.  Default is off.
    */
   void SetEnableEdgesByArray(bool vis);
   int GetEnableEdgesByArray();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array to use for coloring vertices.
    */
   void SetEnabledVerticesArrayName(const char* name);
   const char* GetEnabledVerticesArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to color vertices.  Default is off.
    */
   void SetEnableVerticesByArray(bool vis);
   int GetEnableVerticesByArray();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array used for scaling (if ScaledGlyphs is ON)
    */
   void SetScalingArrayName(const char* name);
   const char* GetScalingArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether to use scaled glyphs or not.  Default is off.
    */
   void SetScaledGlyphs(bool arg);
   bool GetScaledGlyphs();
   vtkBooleanMacro(ScaledGlyphs, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The layout strategy to use when performing the graph layout.
    * The possible strings are:
@@ -231,44 +231,32 @@ public:
    * Default is "Simple 2D".
    */
   void SetLayoutStrategy(const char* name);
-  void SetLayoutStrategyToRandom()
-    { this->SetLayoutStrategy("Random"); }
-  void SetLayoutStrategyToForceDirected()
-    { this->SetLayoutStrategy("Force Directed"); }
-  void SetLayoutStrategyToSimple2D()
-    { this->SetLayoutStrategy("Simple 2D"); }
-  void SetLayoutStrategyToClustering2D()
-    { this->SetLayoutStrategy("Clustering 2D"); }
-  void SetLayoutStrategyToCommunity2D()
-    { this->SetLayoutStrategy("Community 2D"); }
-  void SetLayoutStrategyToFast2D()
-    { this->SetLayoutStrategy("Fast 2D"); }
-  void SetLayoutStrategyToPassThrough()
-    { this->SetLayoutStrategy("Pass Through"); }
-  void SetLayoutStrategyToCircular()
-    { this->SetLayoutStrategy("Circular"); }
-  void SetLayoutStrategyToTree()
-    { this->SetLayoutStrategy("Tree"); }
-  void SetLayoutStrategyToCosmicTree()
-    { this->SetLayoutStrategy("Cosmic Tree"); }
-  void SetLayoutStrategyToCone()
-    { this->SetLayoutStrategy("Cone"); }
-  void SetLayoutStrategyToSpanTree()
-    { this->SetLayoutStrategy("Span Tree"); }
+  void SetLayoutStrategyToRandom() { this->SetLayoutStrategy("Random"); }
+  void SetLayoutStrategyToForceDirected() { this->SetLayoutStrategy("Force Directed"); }
+  void SetLayoutStrategyToSimple2D() { this->SetLayoutStrategy("Simple 2D"); }
+  void SetLayoutStrategyToClustering2D() { this->SetLayoutStrategy("Clustering 2D"); }
+  void SetLayoutStrategyToCommunity2D() { this->SetLayoutStrategy("Community 2D"); }
+  void SetLayoutStrategyToFast2D() { this->SetLayoutStrategy("Fast 2D"); }
+  void SetLayoutStrategyToPassThrough() { this->SetLayoutStrategy("Pass Through"); }
+  void SetLayoutStrategyToCircular() { this->SetLayoutStrategy("Circular"); }
+  void SetLayoutStrategyToTree() { this->SetLayoutStrategy("Tree"); }
+  void SetLayoutStrategyToCosmicTree() { this->SetLayoutStrategy("Cosmic Tree"); }
+  void SetLayoutStrategyToCone() { this->SetLayoutStrategy("Cone"); }
+  void SetLayoutStrategyToSpanTree() { this->SetLayoutStrategy("Span Tree"); }
   const char* GetLayoutStrategyName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The layout strategy to use when performing the graph layout.
    * This signature allows an application to create a layout
    * object directly and simply set the pointer through this method.
    */
   vtkGraphLayoutStrategy* GetLayoutStrategy();
-  void SetLayoutStrategy(vtkGraphLayoutStrategy *s);
-  //@}
+  void SetLayoutStrategy(vtkGraphLayoutStrategy* s);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The layout strategy to use when performing the edge layout.
    * The possible strings are:
@@ -277,29 +265,27 @@ public:
    * Default is "Arc Parallel".
    */
   void SetEdgeLayoutStrategy(const char* name);
-  void SetEdgeLayoutStrategyToArcParallel()
-    { this->SetEdgeLayoutStrategy("Arc Parallel"); }
-  void SetEdgeLayoutStrategyToPassThrough()
-    { this->SetEdgeLayoutStrategy("Pass Through"); }
+  void SetEdgeLayoutStrategyToArcParallel() { this->SetEdgeLayoutStrategy("Arc Parallel"); }
+  void SetEdgeLayoutStrategyToPassThrough() { this->SetEdgeLayoutStrategy("Pass Through"); }
   const char* GetEdgeLayoutStrategyName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The layout strategy to use when performing the edge layout.
    * This signature allows an application to create a layout
    * object directly and simply set the pointer through this method.
    */
   vtkEdgeLayoutStrategy* GetEdgeLayoutStrategy();
-  void SetEdgeLayoutStrategy(vtkEdgeLayoutStrategy *s);
-  //@}
+  void SetEdgeLayoutStrategy(vtkEdgeLayoutStrategy* s);
+  ///@}
 
   /**
    * Associate the icon at index "index" in the vtkTexture to all vertices
    * containing "type" as a value in the vertex attribute array specified by
    * IconArrayName.
    */
-  void AddIconType(const char *type, int index);
+  void AddIconType(const char* type, int index);
 
   /**
    * Clear all icon mappings.
@@ -312,62 +298,62 @@ public:
    */
   void SetIconAlignment(int alignment);
 
-  //@{
+  ///@{
   /**
    * Whether icons are visible (default off).
    */
   void SetIconVisibility(bool b);
   bool GetIconVisibility();
   vtkBooleanMacro(IconVisibility, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The array used for assigning icons
    */
   void SetIconArrayName(const char* name);
   const char* GetIconArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The type of glyph to use for the vertices
    */
   void SetGlyphType(int type);
   int GetGlyphType();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The size of the font used for vertex labeling
    */
   virtual void SetVertexLabelFontSize(const int size);
   virtual int GetVertexLabelFontSize();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The size of the font used for edge labeling
    */
   virtual void SetEdgeLabelFontSize(const int size);
   virtual int GetEdgeLabelFontSize();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether the scalar bar for edges is visible.  Default is off.
    */
   void SetEdgeScalarBarVisibility(bool vis);
   bool GetEdgeScalarBarVisibility();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether the scalar bar for vertices is visible.  Default is off.
    */
   void SetVertexScalarBarVisibility(bool vis);
   bool GetVertexScalarBarVisibility();
-  //@}
+  ///@}
 
   /**
    * Reset the camera based on the bounds of the selected region.
@@ -398,7 +384,7 @@ protected:
   vtkGraphLayoutView();
   ~vtkGraphLayoutView() override;
 
-  //@{
+  ///@{
   /**
    * Overrides behavior in vtkView to create a vtkRenderedGraphRepresentation
    * by default.
@@ -407,7 +393,7 @@ protected:
   virtual vtkRenderedGraphRepresentation* GetGraphRepresentation();
   // Called to process events.  Overrides behavior in vtkRenderView.
   void ProcessEvents(vtkObject* caller, unsigned long eventId, void* callData) override;
-  //@}
+  ///@}
 
 private:
   vtkGraphLayoutView(const vtkGraphLayoutView&) = delete;
