@@ -7,7 +7,7 @@
 #  define VTKIOLSDYNA_NO_EXPORT
 #else
 #  ifndef VTKIOLSDYNA_EXPORT
-#    ifdef vtkIOLSDyna_EXPORTS
+#    ifdef IOLSDyna_EXPORTS
         /* We are building this library */
 #      define VTKIOLSDYNA_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKIOLSDYNA_DEPRECATED
 #  define VTKIOLSDYNA_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOLSDYNA_DEPRECATED_EXPORT VTKIOLSDYNA_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOLSDYNA_DEPRECATED_NO_EXPORT VTKIOLSDYNA_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOLSDYNA_NO_DEPRECATED
+#ifndef VTKIOLSDYNA_DEPRECATED_EXPORT
+#  define VTKIOLSDYNA_DEPRECATED_EXPORT VTKIOLSDYNA_EXPORT VTKIOLSDYNA_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIOLSDYNA_DEPRECATED_NO_EXPORT
+#  define VTKIOLSDYNA_DEPRECATED_NO_EXPORT VTKIOLSDYNA_NO_EXPORT VTKIOLSDYNA_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOLSDYNA_NO_DEPRECATED
+#    define VTKIOLSDYNA_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKIOLSDYNA_EXPORT_H */
